# Documentation for `PipelineElement`
::: photonai.base.PipelineElement
    selection:
      members:
        - __init__
        - create
        - __iadd__
        - fit
        - predict
        - transform
        - inverse_transform
        - score
